#!/usr/bin/env python3

from gi.repository import Gtk, GLib, GdkPixbuf

class ComipoliThumbnail(Gtk.Dialog):
    def __init__(self, owner):
        Gtk.Dialog.__init__(self, transient_for=owner, title='Comipoli Thumbnail')
        self.owner = owner
        self.fbox = Gtk.FlowBox(
            valign=Gtk.Align.START,
            max_children_per_line=10,
            homogeneous=True,
            selection_mode=Gtk.SelectionMode.BROWSE)
        self.fbox.connect('child-activated', self.on_flowbox_child_activated)
        scroll = Gtk.ScrolledWindow()
        scroll.add(self.fbox)
        self.vbox.pack_start(scroll, True, True, 0)
        # size
        x, y = self.owner.get_size()
        self.resize(x, y)
        self.show_all()
        # idle
        self.generator = self.add_thumbnail()
        GLib.idle_add(self.idle_function)

    def idle_function(self):
        try:
            next(self.generator)
            return True
        except StopIteration:
            return False

    def add_thumbnail(self):
        for num, buf in enumerate(self.owner.thumbnail_array):
            image = Gtk.Image(pixbuf=buf, visible=True)
            label = Gtk.Label(
                label='<span color="#ff0000" background="#66ffff" background_alpha="50%">{0}</span>'.format(num+1),
                use_markup=True,
                visible=True,
                halign=Gtk.Align.CENTER,
                valign=Gtk.Align.END)
            overlay = Gtk.Overlay(visible=True)
            overlay.add(image)
            overlay.add_overlay(label)
            self.fbox.add(overlay)
            # Focus
            if num == self.owner.num:
                child = self.fbox.get_child_at_index(num)
                self.fbox.select_child(child)
                self.set_focus(child)
            yield 1

    def on_flowbox_child_activated(self, fbox, child):
        num = child.get_index()
        self.owner.num = num - 1
        self.owner.change_pixbuf(1)
        self.hide()

